"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const family_1 = require("../models/family");
const unit_1 = require("../models/unit");
const utils_1 = require("../utils");
const getSpouses_1 = require("../utils/getSpouses");
const setUnitDefShifts_1 = require("../utils/setUnitDefShifts");
exports.default = (store) => {
    return function (parentIDs, type = 'root', isMain = false) {
        const family = new family_1.default(store.getNextId(), type, isMain);
        const parents = parentIDs.map(store.getNode.bind(store));
        if (family.main)
            parents.sort((a, b) => (b.gender !== store.gender) ? -1 : 0);
        family.pUnits.push(new unit_1.default(family.id, parents));
        let children = [];
        if (parents.length === 1) {
            children = parents[0].children.map(utils_1.relToNode(store));
        }
        else {
            const firstParent = parents[0];
            const secondParent = parents[1];
            children = firstParent.children
                .filter(rel => secondParent.children.find(utils_1.withId(rel.id)))
                .map(utils_1.relToNode(store));
        }
        children.forEach(child => {
            if (child.spouses.length) {
                const { left, middle, right } = getSpouses_1.default(store, [child]);
                [...left.map(node => [node]), middle, ...right.map(node => [node])].forEach(nodes => (family.cUnits.push(new unit_1.default(family.id, nodes, true))));
            }
            else {
                family.cUnits.push(new unit_1.default(family.id, [child], true));
            }
        });
        setUnitDefShifts_1.default(family);
        return family;
    };
};
//# sourceMappingURL=byParents.js.map