"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const byParents_1 = require("../children/byParents");
const getSpouses_1 = require("../utils/getSpouses");
const fixOverlaps_1 = require("./fixOverlaps");
const utils_1 = require("../utils");
exports.default = (store) => {
    let families = [];
    const createFamily = byParents_1.default(store);
    if (utils_1.hasDiffParents(store.rootNode)) {
        const bloodParentIDs = store.rootNode.parents
            .filter(utils_1.withType('blood'))
            .map(utils_1.prop('id'));
        const adoptedParentIDs = store.rootNode.parents
            .filter(utils_1.withType('adopted'))
            .map(utils_1.prop('id'));
        const bloodFamily = createFamily(bloodParentIDs, 'root', true);
        const adoptedFamily = createFamily(adoptedParentIDs);
        fixOverlaps_1.default(bloodFamily, adoptedFamily);
        families = [bloodFamily, adoptedFamily];
    }
    else {
        const parentIDs = store.rootNode.parents.map(utils_1.prop('id'));
        const mainFamily = createFamily(parentIDs, 'root', true);
        families.push(mainFamily);
        const parents = mainFamily.pUnits
            .map(utils_1.prop('nodes'))
            .reduce(utils_1.flat);
        if (parents.length === 2) {
            const { left, right } = getSpouses_1.default(store, parents);
            families = [
                ...left.map(node => createFamily([node.id])),
                ...families,
                ...right.map(node => createFamily([node.id])),
            ];
        }
    }
    if (families.length > 1) {
        for (let i = 1; i < families.length; i++) {
            families[i].left = families[i - 1].right;
        }
    }
    families.forEach(family => store.families.set(family.id, family));
    return store;
};
//# sourceMappingURL=create.js.map